@@ -5,14 +5,11 @@
 
 #include "differentiateassistant.h"
 
-#include <QAction>
-#include <QIcon>
 #include <QDialog>
 #include <QPushButton>
 #include <QStyle>
 
 #include <KActionCollection>
-#include <KConfigGroup>
 #include "ui_differentiatedlg.h"
 #include "cantor_macros.h"
 #include "backend.h"
@@ -26,7 +23,7 @@ DifferentiateAssistant::DifferentiateAssistant(QObject* parent, QList<QVariant>
 void DifferentiateAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_differentiate_assistant.rc"));
-    QAction* differentiate=new QAction(i18n("Differentiate"), actionCollection());
+    auto* differentiate = new QAction(i18n("Differentiate"), actionCollection());
     differentiate->setIcon(QIcon::fromTheme(icon()));
     actionCollection()->addAction(QLatin1String("differentiate_assistant"), differentiate);
     connect(differentiate, &QAction::triggered, this, &DifferentiateAssistant::requested);
@@ -35,29 +32,29 @@ void DifferentiateAssistant::initActions()
 QStringList DifferentiateAssistant::run(QWidget* parent)
 {
     QPointer<QDialog> dlg=new QDialog(parent);
-    QWidget* widget=new QWidget(dlg);
+    auto* widget = new QWidget(dlg);
     Ui::DifferentiateAssistantBase base;
     base.setupUi(widget);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     dlg->setLayout(mainLayout);
     mainLayout->addWidget(widget);
 
     base.buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
     base.buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
-    connect(base.buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()));
-    connect(base.buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()));
+    connect(base.buttonBox, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
+    connect(base.buttonBox, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
 
     QStringList result;
     if( dlg->exec())
     {
-        QString expression=base.expression->text();
-        QString variable=base.variable->text();
-        int times=base.times->value();
-
-        Cantor::CalculusExtension* ext=
-            dynamic_cast<Cantor::CalculusExtension*>(backend()->extension(QLatin1String("CalculusExtension")));
-
-        result<<ext->differentiate(expression, variable, times);
+        auto* ext = dynamic_cast<Cantor::CalculusExtension*>(backend()->extension(QLatin1String("CalculusExtension")));
+        if (ext)
+        {
+            const auto& expression = base.expression->text();
+            const auto& variable = base.variable->text();
+            const int times = base.times->value();
+            result << ext->differentiate(expression, variable, times);
+        }
     }
 
     delete dlg;
