@@ -16,7 +16,11 @@ RSettingsWidget::RSettingsWidget(QWidget *parent, const QString& id) : BackendSe
     setupUi(this);
 
     m_tabWidget = tabWidget;
+#ifdef HAVE_EMBEDDED_DOCUMENTATION
     m_tabDocumentation = tabDocumentation;
+#else
+    tabWidget->removeTab(2);
+#endif
     connect(tabWidget, &QTabWidget::currentChanged, this, &BackendSettingsWidget::tabChanged);
 
     kcfg_autorunScripts->lineEdit()->setReadOnly(true);
