@@ -25,7 +25,11 @@ JuliaSettingsWidget::JuliaSettingsWidget(QWidget* parent, const QString& id) : B
     setupUi(this);
 
     m_tabWidget = tabWidget;
+#ifdef HAVE_EMBEDDED_DOCUMENTATION
     m_tabDocumentation = tabDocumentation;
+#else
+    tabWidget->removeTab(2);
+#endif
 
     connect(tabWidget, &QTabWidget::currentChanged, this, &BackendSettingsWidget::tabChanged);
 }
