@@ -36,7 +36,7 @@ LuaSession::~LuaSession()
 
 void LuaSession::login()
 {
-    emit loginStarted();
+    Q_EMIT loginStarted();
 
     m_process = new QProcess(this);
 
@@ -56,8 +56,8 @@ void LuaSession::login()
     if (!m_process->waitForStarted())
     {
         changeStatus(Session::Disable);
-        emit error(i18n("Failed to start Lua, please check Lua installation."));
-        emit loginDone();
+        Q_EMIT error(i18n("Failed to start Lua, please check Lua installation."));
+        Q_EMIT loginDone();
         delete m_process;
         m_process = nullptr;
         return;
@@ -72,7 +72,7 @@ void LuaSession::login()
     luaL_openlibs(m_L);
 
     changeStatus(Cantor::Session::Done);
-    emit loginDone();
+    Q_EMIT loginDone();
 }
 
 bool LuaSession::isLuaJIT() const
