@@ -25,16 +25,16 @@ void QalculateCompletionObject::fetchIdentifierType()
 {
     Variable* var = CALCULATOR->getVariable(identifier().toLatin1().data());
     if (var) {
-        emit fetchingTypeDone(VariableType);
+        Q_EMIT fetchingTypeDone(VariableType);
         return;
     }
     MathFunction* func = CALCULATOR->getFunction(identifier().toLatin1().data());
     if (!func) // can this happen?
-        emit fetchingTypeDone(UnknownType);
+        Q_EMIT fetchingTypeDone(UnknownType);
     else if (func->args() == 0)
-        emit fetchingTypeDone(FunctionWithoutArguments);
+        Q_EMIT fetchingTypeDone(FunctionWithoutArguments);
     else
-        emit fetchingTypeDone(FunctionWithArguments);
+        Q_EMIT fetchingTypeDone(FunctionWithArguments);
 }
 
 int QalculateCompletionObject::locateIdentifier(const QString& cmd, int index) const
@@ -59,30 +59,30 @@ void QalculateCompletionObject::fetchCompletions()
     // Matching Qt::CaseInsensitive here does not help, because a) Qalculate
     // does distinguish cases, and b) KCompletion::makeCompletion matches
     // case sensitive.
-    foreach ( Unit* item, CALCULATOR->units ) {
+    for (Unit* item : CALCULATOR->units) {
         //TODO: this is fugily...
         QString str(QLatin1String(item->name(true).c_str()));
         if ( str.startsWith(command(), Qt::CaseSensitive) ) {
             comp << str;
         }
-    QString str2(QLatin1String(item->singular().c_str()));
-    if (str2.startsWith(command(), Qt::CaseSensitive) ) {
-        comp << str2;
+        QString str2(QLatin1String(item->singular().c_str()));
+        if (str2.startsWith(command(), Qt::CaseSensitive) ) {
+            comp << str2;
+        }
+        // Also include the plural form for completion?
+        //QString str3(item->plural().c_str());
+        //if (str3.startsWith(command(), Qt::CaseSensitive) ) {
+        //    comp << str3;
+        //}
     }
-    // Also include the plural form for completion?
-    //QString str3(item->plural().c_str());
-    //if (str3.startsWith(command(), Qt::CaseSensitive) ) {
-    //    comp << str3;
-    //}
-    }
-    foreach ( ExpressionItem* item, CALCULATOR->variables ) {
+    for ( ExpressionItem* item : CALCULATOR->variables ) {
         //TODO: this is fugly...
         QString str(QLatin1String(item->name(true).c_str()));
         if ( str.startsWith(command(), Qt::CaseSensitive) ) {
             comp << str;
         }
     }
-    foreach ( ExpressionItem* item, CALCULATOR->functions ) {
+    for ( ExpressionItem* item : CALCULATOR->functions) {
         //TODO: this is fugly...
         QString str(QLatin1String(item->name(true).c_str()));
         if ( str.startsWith(command(), Qt::CaseSensitive) ) {
@@ -91,5 +91,5 @@ void QalculateCompletionObject::fetchCompletions()
     }
 
     setCompletions(comp);
-    emit fetchingDone();
+    Q_EMIT fetchingDone();
 }
