@@ -5,13 +5,12 @@
 
 #include "scilabkeywords.h"
 
-#include <QStringList>
 #include <QXmlStreamReader>
 #include <QtAlgorithms>
 #include <QDebug>
 
-#include <repository.h>
-#include <KF5/KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/Repository>
+#include <KSyntaxHighlighting/Definition>
 
 ScilabKeywords::ScilabKeywords()
 {
